@@ -24,12 +24,14 @@ import getpass
 import logging
 import os
 import sys
+import uuid
 
 from turbinia import config
 from turbinia.config import logger
 from turbinia.lib import libcloudforensics
 from turbinia import __version__
 from turbinia.processors import archive
+from turbinia.output_manager import OutputManager
 
 log = logging.getLogger('turbinia')
 # We set up the logger first without the file handler, and we will set up the
@@ -279,9 +281,9 @@ def main():
 
   # Parser options for CompressedDirectory evidence type
   parser_compressed_directory = subparsers.add_parser(
-      'compressedirectory', help='Process a compressed tar file as Evidence')
+      'compresseddirectory', help='Process a compressed tar file as Evidence')
   parser_compressed_directory.add_argument(
-      '-l', '--local_path', help='Local path to the evidence', required=True)
+      '-l', '--source_path', help='Local path to the evidence', required=True)
   parser_compressed_directory.add_argument(
       '-s', '--source', help='Description of the source of the evidence',
       required=False)
@@ -479,6 +481,9 @@ def main():
         log.info('--copy_only specified, so not processing with Turbinia')
         sys.exit(0)
 
+  # Set request id
+  request_id = args.request_id if args.request_id else uuid.uuid4().hex
+
   # Start Evidence configuration
   evidence_ = None
   if args.command == 'rawdisk':
@@ -510,7 +515,7 @@ def main():
     local_path = os.path.abspath(args.local_path)
     evidence_ = evidence.Directory(
         name=args.name, local_path=local_path, source=args.source)
-  elif args.command == 'compressedirectory':
+  elif args.command == 'compresseddirectory':
     archive.ValidateTarFile(args.source_path)
     args.name = args.name if args.name else args.source_path
     source_path = os.path.abspath(args.source_path)
@@ -613,6 +618,16 @@ def main():
           'The evidence type {0:s} is Cloud only, and this instance of '
           'Turbinia is not a cloud instance.'.format(evidence_.type))
       sys.exit(1)
+    elif not config.SHARED_FILESYSTEM and evidence_.copyable:
+      if os.path.exists(evidence_.local_path):
+        output_manager = OutputManager()
+        output_manager.setup(evidence_.type, request_id, remote_only=True)
+        output_manager.save_evidence(evidence_)
+      else:
+        log.error(
+            'The evidence local path does not exist: {0:s}. Please submit '
+            'a new Request with a valid path.'.format(evidence_.local_path))
+        sys.exit(1)
     elif not config.SHARED_FILESYSTEM and not evidence_.cloud_only:
       log.error(
           'The evidence type {0:s} cannot run on Cloud instances of '
@@ -632,7 +647,7 @@ def main():
     server.start()
   elif evidence_:
     request = TurbiniaRequest(
-        request_id=args.request_id, requester=getpass.getuser())
+        request_id=request_id, requester=getpass.getuser())
     request.evidence.append(evidence_)
     if filter_patterns:
       request.recipe['filter_patterns'] = filter_patterns
